==> jc-1.4.0.tar.gz: javax/naming/CannotProceedException.h <==
// public class javax.naming.CannotProceedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 700efecbad8d7041 javax_naming_CannotProceedException
// @dep_class fadee18b7599c8d5 javax_naming_NamingException

// header file dependencies
// @dep_header javax_naming_NamingException

#include "javax/naming/NamingException.h"

#ifndef _JC_javax_naming_CannotProceedException_H_
#define _JC_javax_naming_CannotProceedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_Context$object;
struct _jc_javax_naming_Name$object;

// Typedefs
typedef struct _jc_javax_naming_CannotProceedException$sub_refs	_jc_javax_naming_CannotProceedException$sub_refs;
typedef struct _jc_javax_naming_CannotProceedException$sub_nonrefs	_jc_javax_naming_CannotProceedException$sub_nonrefs;
typedef struct _jc_javax_naming_CannotProceedException$refs	_jc_javax_naming_CannotProceedException$refs;
typedef struct _jc_javax_naming_CannotProceedException$nonrefs	_jc_javax_naming_CannotProceedException$nonrefs;
typedef struct _jc_javax_naming_CannotProceedException$object	_jc_javax_naming_CannotProceedException$object;

typedef const struct _jc_javax_naming_CannotProceedException$vmethods	_jc_javax_naming_CannotProceedException$vmethods;
typedef const struct _jc_javax_naming_CannotProceedException$vtable	_jc_javax_naming_CannotProceedException$vtable;
typedef const struct _jc_javax_naming_CannotProceedException$vtype	_jc_javax_naming_CannotProceedException$vtype;

// Constructors
extern void _jc_javax_naming_CannotProceedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
extern void _jc_javax_naming_CannotProceedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_naming_CannotProceedException$method$getAltName$541d2c13926563c5(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
extern struct _jc_object *_jc_javax_naming_CannotProceedException$method$getAltNameCtx$145cc87e6aca6256(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
extern struct _jc_java_util_Hashtable$object *_jc_javax_naming_CannotProceedException$method$getEnvironment$dae7c5e77ff352fb(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
extern struct _jc_object *_jc_javax_naming_CannotProceedException$method$getRemainingNewName$f7386ced43d8788f(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
extern void _jc_javax_naming_CannotProceedException$method$setAltName$c43db77b7bb87cc3(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *);
extern void _jc_javax_naming_CannotProceedException$method$setAltNameCtx$9e27bc53b50bbbe9(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *);
extern void _jc_javax_naming_CannotProceedException$method$setEnvironment$620809d4d7e2b4fb(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_java_util_Hashtable$object *);
extern void _jc_javax_naming_CannotProceedException$method$setRemainingNewName$6ae2f17a4363999f(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$getAltName$541d2c13926563c5;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$getAltNameCtx$145cc87e6aca6256;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$getEnvironment$dae7c5e77ff352fb;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$getRemainingNewName$f7386ced43d8788f;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$setAltName$c43db77b7bb87cc3;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$setAltNameCtx$9e27bc53b50bbbe9;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$setEnvironment$620809d4d7e2b4fb;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$setRemainingNewName$6ae2f17a4363999f;

// Virtual methods structure
struct _jc_javax_naming_CannotProceedException$vmethods {
	struct _jc_object	*(*getAltName$541d2c13926563c5)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
	struct _jc_object	*(*getAltNameCtx$145cc87e6aca6256)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
	struct _jc_java_util_Hashtable$object	*(*getEnvironment$dae7c5e77ff352fb)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
	struct _jc_object	*(*getRemainingNewName$f7386ced43d8788f)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
	void	(*setAltName$c43db77b7bb87cc3)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *);
	void	(*setAltNameCtx$9e27bc53b50bbbe9)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *);
	void	(*setEnvironment$620809d4d7e2b4fb)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_java_util_Hashtable$object *);
	void	(*setRemainingNewName$6ae2f17a4363999f)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_naming_CannotProceedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_CannotProceedException$vmethods	javax_naming_CannotProceedException;
};

// Vtype
struct _jc_javax_naming_CannotProceedException$vtype {
	_jc_type			type;
	_jc_javax_naming_CannotProceedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_CannotProceedException$sub_refs {
	struct _jc_object	*remainingNewName;
	struct _jc_java_util_Hashtable$object	*environment;
	struct _jc_object	*altName;
	struct _jc_object	*altNameCtx;
};

// Reference instance fields (object)
struct _jc_javax_naming_CannotProceedException$refs {
    _jc_javax_naming_CannotProceedException$sub_refs	javax_naming_CannotProceedException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_CannotProceedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_CannotProceedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_CannotProceedException$sub_nonrefs	javax_naming_CannotProceedException;
};

// Object instance structure
struct _jc_javax_naming_CannotProceedException$object {
	_jc_javax_naming_CannotProceedException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_CannotProceedException$vtype	*vtype;
	_jc_javax_naming_CannotProceedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_CannotProceedException$vtype _jc_javax_naming_CannotProceedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_CannotProceedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_CannotProceedException$class_object;

#endif	/* _JC_javax_naming_CannotProceedException_H_ */

==> jc-1.4.6.tar.gz: javax/naming/CannotProceedException.h <==
// public class javax.naming.CannotProceedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 700efecbad8d7041 javax_naming_CannotProceedException
// @dep_class fadee18b7599c8d5 javax_naming_NamingException

// header file dependencies
// @dep_header javax_naming_NamingException

#include "javax/naming/NamingException.h"

#ifndef _JC_javax_naming_CannotProceedException_H_
#define _JC_javax_naming_CannotProceedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_Context$object;
struct _jc_javax_naming_Name$object;

// Typedefs
typedef struct _jc_javax_naming_CannotProceedException$sub_refs	_jc_javax_naming_CannotProceedException$sub_refs;
typedef struct _jc_javax_naming_CannotProceedException$sub_nonrefs	_jc_javax_naming_CannotProceedException$sub_nonrefs;
typedef struct _jc_javax_naming_CannotProceedException$refs	_jc_javax_naming_CannotProceedException$refs;
typedef struct _jc_javax_naming_CannotProceedException$nonrefs	_jc_javax_naming_CannotProceedException$nonrefs;
typedef struct _jc_javax_naming_CannotProceedException$object	_jc_javax_naming_CannotProceedException$object;

typedef const struct _jc_javax_naming_CannotProceedException$vmethods	_jc_javax_naming_CannotProceedException$vmethods;
typedef const struct _jc_javax_naming_CannotProceedException$vtable	_jc_javax_naming_CannotProceedException$vtable;
typedef const struct _jc_javax_naming_CannotProceedException$vtype	_jc_javax_naming_CannotProceedException$vtype;

// Constructors
extern void _jc_javax_naming_CannotProceedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_CannotProceedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_naming_CannotProceedException$method$getAltName$541d2c13926563c5(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_CannotProceedException$method$getAltNameCtx$145cc87e6aca6256(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_Hashtable$object *_jc_javax_naming_CannotProceedException$method$getEnvironment$dae7c5e77ff352fb(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_CannotProceedException$method$getRemainingNewName$f7386ced43d8788f(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_CannotProceedException$method$setAltName$c43db77b7bb87cc3(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_CannotProceedException$method$setAltNameCtx$9e27bc53b50bbbe9(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_CannotProceedException$method$setEnvironment$620809d4d7e2b4fb(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_CannotProceedException$method$setRemainingNewName$6ae2f17a4363999f(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$getAltName$541d2c13926563c5;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$getAltNameCtx$145cc87e6aca6256;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$getEnvironment$dae7c5e77ff352fb;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$getRemainingNewName$f7386ced43d8788f;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$setAltName$c43db77b7bb87cc3;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$setAltNameCtx$9e27bc53b50bbbe9;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$setEnvironment$620809d4d7e2b4fb;
extern _jc_method _jc_javax_naming_CannotProceedException$method_info$setRemainingNewName$6ae2f17a4363999f;

// Virtual methods structure
struct _jc_javax_naming_CannotProceedException$vmethods {
	struct _jc_object	*(*getAltName$541d2c13926563c5)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAltNameCtx$145cc87e6aca6256)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_Hashtable$object	*(*getEnvironment$dae7c5e77ff352fb)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getRemainingNewName$f7386ced43d8788f)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
	void	(*setAltName$c43db77b7bb87cc3)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setAltNameCtx$9e27bc53b50bbbe9)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setEnvironment$620809d4d7e2b4fb)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
	void	(*setRemainingNewName$6ae2f17a4363999f)(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_CannotProceedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_CannotProceedException$vmethods	javax_naming_CannotProceedException;
};

// Vtype
struct _jc_javax_naming_CannotProceedException$vtype {
	_jc_type			type;
	_jc_javax_naming_CannotProceedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_CannotProceedException$sub_refs {
	struct _jc_object	*remainingNewName;
	struct _jc_java_util_Hashtable$object	*environment;
	struct _jc_object	*altName;
	struct _jc_object	*altNameCtx;
};

// Reference instance fields (object)
struct _jc_javax_naming_CannotProceedException$refs {
    _jc_javax_naming_CannotProceedException$sub_refs	javax_naming_CannotProceedException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_CannotProceedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_CannotProceedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_CannotProceedException$sub_nonrefs	javax_naming_CannotProceedException;
};

// Object instance structure
struct _jc_javax_naming_CannotProceedException$object {
	_jc_javax_naming_CannotProceedException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_CannotProceedException$vtype	*vtype;
	_jc_javax_naming_CannotProceedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_CannotProceedException$vtype _jc_javax_naming_CannotProceedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_CannotProceedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_CannotProceedException$class_object;

#endif	/* _JC_javax_naming_CannotProceedException_H_ */
